@@ -25,15 +25,17 @@
  *	needed to deal with TCP connections.
  */
 
-#include <sys/cdefs.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <stdio.h>
 #include <syslog.h>
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <netdb.h>
-#include <sys/signal.h>
-#include <sys/errno.h>
+#include <signal.h>
+#include <errno.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -42,8 +44,8 @@
 #include <rpc/rpcb_prot.h>
 //#include <clnt_soc.h>
 #include <sys/select.h>
-#undef NIS
-#include <rpcsvc/nis.h>
+
+#include "nis.h"
 
 
 #ifdef TESTING
